@@ -8,7 +8,6 @@ from typing import TYPE_CHECKING, Any, cast
 import ibis
 import ibis.expr.types as ir
 
-from narwhals._compliant import LazyNamespace
 from narwhals._expression_parsing import (
     combine_alias_output_names,
     combine_evaluate_output_names,
@@ -16,7 +15,8 @@ from narwhals._expression_parsing import (
 from narwhals._ibis.dataframe import IbisLazyFrame
 from narwhals._ibis.expr import IbisExpr
 from narwhals._ibis.selectors import IbisSelectorNamespace
-from narwhals._ibis.utils import lit, narwhals_to_native_dtype
+from narwhals._ibis.utils import function, lit, narwhals_to_native_dtype
+from narwhals._sql.namespace import SQLNamespace
 from narwhals._sql.when_then import SQLThen, SQLWhen
 from narwhals._utils import Implementation, requires
 
@@ -24,10 +24,10 @@ if TYPE_CHECKING:
     from collections.abc import Iterable, Sequence
 
     from narwhals._utils import Version
-    from narwhals.typing import ConcatMethod, IntoDType
+    from narwhals.typing import ConcatMethod, IntoDType, PythonLiteral
 
 
-class IbisNamespace(LazyNamespace[IbisLazyFrame, IbisExpr, "ir.Table"]):
+class IbisNamespace(SQLNamespace[IbisLazyFrame, IbisExpr, "ir.Table", "ir.Value"]):
     _implementation: Implementation = Implementation.IBIS
 
     def __init__(self, *, version: Version) -> None:
@@ -45,6 +45,22 @@ class IbisNamespace(LazyNamespace[IbisLazyFrame, IbisExpr, "ir.Table"]):
     def _lazyframe(self) -> type[IbisLazyFrame]:
         return IbisLazyFrame
 
+    def _function(self, name: str, *args: ir.Value | PythonLiteral) -> ir.Value:
+        return function(name, *args)
+
+    def _lit(self, value: Any) -> ir.Value:
+        return lit(value)
+
+    def _when(
+        self, condition: ir.Value, value: ir.Value, otherwise: ir.Expr | None = None
+    ) -> ir.Value:
+        if otherwise is None:
+            return ibis.cases((condition, value))
+        return ibis.cases((condition, value), else_=otherwise)  # pragma: no cover
+
+    def _coalesce(self, *exprs: ir.Value) -> ir.Value:
+        return ibis.coalesce(*exprs)
+
     def concat(
         self, items: Iterable[IbisLazyFrame], *, how: ConcatMethod
     ) -> IbisLazyFrame:
@@ -84,47 +100,6 @@ class IbisNamespace(LazyNamespace[IbisLazyFrame, IbisExpr, "ir.Table"]):
             version=self._version,
         )
 
-    def all_horizontal(self, *exprs: IbisExpr, ignore_nulls: bool) -> IbisExpr:
-        def func(cols: Iterable[ir.Value]) -> ir.Value:
-            it = (
-                (col.fill_null(lit(True)) for col in cols)  # noqa: FBT003
-                if ignore_nulls
-                else cols
-            )
-            return reduce(operator.and_, it)
-
-        return self._expr._from_elementwise_horizontal_op(func, *exprs)
-
-    def any_horizontal(self, *exprs: IbisExpr, ignore_nulls: bool) -> IbisExpr:
-        def func(cols: Iterable[ir.Value]) -> ir.Value:
-            it = (
-                (col.fill_null(lit(False)) for col in cols)  # noqa: FBT003
-                if ignore_nulls
-                else cols
-            )
-            return reduce(operator.or_, it)
-
-        return self._expr._from_elementwise_horizontal_op(func, *exprs)
-
-    def max_horizontal(self, *exprs: IbisExpr) -> IbisExpr:
-        def func(cols: Iterable[ir.Value]) -> ir.Value:
-            return ibis.greatest(*cols)
-
-        return self._expr._from_elementwise_horizontal_op(func, *exprs)
-
-    def min_horizontal(self, *exprs: IbisExpr) -> IbisExpr:
-        def func(cols: Iterable[ir.Value]) -> ir.Value:
-            return ibis.least(*cols)
-
-        return self._expr._from_elementwise_horizontal_op(func, *exprs)
-
-    def sum_horizontal(self, *exprs: IbisExpr) -> IbisExpr:
-        def func(cols: Iterable[ir.Value]) -> ir.Value:
-            cols = (col.fill_null(lit(0)) for col in cols)
-            return reduce(operator.add, cols)
-
-        return self._expr._from_elementwise_horizontal_op(func, *exprs)
-
     def mean_horizontal(self, *exprs: IbisExpr) -> IbisExpr:
         def func(cols: Iterable[ir.Value]) -> ir.Value:
             cols = list(cols)
@@ -161,12 +136,6 @@ class IbisNamespace(LazyNamespace[IbisLazyFrame, IbisExpr, "ir.Table"]):
             version=self._version,
         )
 
-    def coalesce(self, *exprs: IbisExpr) -> IbisExpr:
-        def func(cols: Iterable[ir.Value]) -> ir.Value:
-            return ibis.coalesce(*cols)
-
-        return self._expr._from_elementwise_horizontal_op(func, *exprs)
-
 
 class IbisWhen(SQLWhen["IbisLazyFrame", "ir.Value", IbisExpr]):
     lit = lit
