@@ -8,7 +8,13 @@ import pyarrow as pa
 import pytest
 
 import narwhals as nw
-from tests.utils import DASK_VERSION, PANDAS_VERSION, Constructor, assert_equal_data
+from tests.utils import (
+    CUDF_VERSION,
+    DASK_VERSION,
+    PANDAS_VERSION,
+    Constructor,
+    assert_equal_data,
+)
 
 if TYPE_CHECKING:
     from narwhals.dtypes import DType
@@ -109,8 +115,11 @@ def test_lit_operation_in_with_columns(
 
 @pytest.mark.skipif(PANDAS_VERSION < (1, 5), reason="too old for pyarrow")
 def test_date_lit(constructor: Constructor, request: pytest.FixtureRequest) -> None:
-    if "dask" in str(constructor):
-        # https://github.com/dask/dask/issues/11637
+    # https://github.com/dask/dask/issues/11637
+    if "dask" in str(constructor) or (
+        # https://github.com/rapidsai/cudf/pull/18832
+        "cudf" in str(constructor) and CUDF_VERSION >= (25, 8, 0)
+    ):
         request.applymarker(pytest.mark.xfail)
     df = nw.from_native(constructor({"a": [1]}))
     result = df.with_columns(nw.lit(date(2020, 1, 1), dtype=nw.Date)).collect_schema()
