@@ -4,9 +4,7 @@ import pytest
 
 import narwhals as nw
 from narwhals.exceptions import InvalidOperationError
-from tests.utils import Constructor
-from tests.utils import ConstructorEager
-from tests.utils import assert_equal_data
+from tests.utils import Constructor, ConstructorEager, assert_equal_data
 
 data = {
     "a": [3, 8, 2, None],
@@ -53,14 +51,12 @@ def test_median_expr_raises_on_str(
     df = nw.from_native(constructor(data))
     if isinstance(df, nw.LazyFrame):
         with pytest.raises(
-            InvalidOperationError,
-            match="`median` operation not supported",
+            InvalidOperationError, match="`median` operation not supported"
         ):
             df.select(expr).lazy().collect()
     else:
         with pytest.raises(
-            InvalidOperationError,
-            match="`median` operation not supported",
+            InvalidOperationError, match="`median` operation not supported"
         ):
             df.select(expr)
 
