@@ -3,13 +3,9 @@ from __future__ import annotations
 import numpy as np
 
 import narwhals as nw
-from tests.utils import ConstructorEager
-from tests.utils import assert_equal_data
+from tests.utils import ConstructorEager, assert_equal_data
 
-data = {
-    "a": ["foo", "bars"],
-    "ab": ["foo", "bars"],
-}
+data = {"a": ["foo", "bars"], "ab": ["foo", "bars"]}
 
 
 def test_with_columns(constructor_eager: ConstructorEager) -> None:
