@@ -40,11 +40,13 @@ from tests.utils import (
 )
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
+
     from typing_extensions import assert_type
 
     from narwhals._namespace import EagerAllowed
     from narwhals.stable.v1.typing import IntoDataFrameT
-    from narwhals.typing import _2DArray
+    from narwhals.typing import IntoDType, _1DArray, _2DArray
     from tests.utils import Constructor, ConstructorEager
 
 
@@ -615,7 +617,8 @@ def test_series_recursive_v1() -> None:
 
     pl_series = pl.Series(name="test", values=[1, 2, 3])
     nw_series = nw_v1.from_native(pl_series, series_only=True)
-    with pytest.raises(AttributeError):
+    # NOTE: (#2629) combined with passing in `nw_v1.Series` (w/ a `_version`) into itself changes the error
+    with pytest.raises(AssertionError):
         nw_v1.Series(nw_series, level="full")
 
     nw_series_early_return = nw_v1.from_native(nw_series, series_only=True)
@@ -1022,3 +1025,27 @@ def test_dataframe_from_numpy(eager_backend: EagerAllowed) -> None:
         assert isinstance(result_schema, nw_v1.Schema)
 
     assert isinstance(result_schema, nw.Schema)
+
+
+@pytest.mark.parametrize(
+    ("dtype", "expected"),
+    [
+        (None, [5, 2, 0, 1]),
+        (nw_v1.Int64, [5, 2, 0, 1]),
+        (nw_v1.Int16(), [5, 2, 0, 1]),
+        (nw_v1.Float64, [5.0, 2.0, 0.0, 1.0]),
+        (nw_v1.Float32(), [5.0, 2.0, 0.0, 1.0]),
+    ],
+    ids=str,
+)
+def test_series_from_numpy(
+    eager_backend: EagerAllowed, dtype: IntoDType | None, expected: Sequence[Any]
+) -> None:
+    arr: _1DArray = cast("_1DArray", np.array([5, 2, 0, 1]))
+    name = "abc"
+    result = nw_v1.Series.from_numpy(name, arr, backend=eager_backend, dtype=dtype)
+    assert result._version is Version.V1
+    assert isinstance(result, nw_v1.Series)
+    if dtype:
+        assert result.dtype == dtype
+    assert_equal_data(result.to_frame(), {name: expected})
